==> apache-camel-2.23.2-src.zip: apache-camel-2.23.2/components/camel-jacksonxml/src/test/java/org/apache/camel/component/jacksonxml/JacksonJsonDataFormatTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.jacksonxml;

import org.apache.camel.builder.RouteBuilder;

public class JacksonJsonDataFormatTest extends JacksonMarshalTest {

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                from("direct:in").marshal().jacksonxml();
                from("direct:back").unmarshal().jacksonxml().to("mock:reverse");

                from("direct:inPretty").marshal().jacksonxml(true);
                from("direct:backPretty").unmarshal().jacksonxml().to("mock:reverse");

                from("direct:inPojo").marshal().jacksonxml();
                from("direct:backPojo").unmarshal().jacksonxml(TestPojo.class).to("mock:reversePojo");
            }
        };
    }

}

==> apache-camel-3.16.0-src.zip: apache-camel-3.16.0/components/camel-jacksonxml/src/test/java/org/apache/camel/component/jacksonxml/JacksonJsonDataFormatTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.jacksonxml;

import org.apache.camel.builder.RouteBuilder;

public class JacksonJsonDataFormatTest extends JacksonMarshalTest {

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                from("direct:in").marshal().jacksonXml();
                from("direct:back").unmarshal().jacksonXml().to("mock:reverse");

                from("direct:inPretty").marshal().jacksonXml(true);
                from("direct:backPretty").unmarshal().jacksonXml().to("mock:reverse");

                from("direct:inPojo").marshal().jacksonXml();
                from("direct:backPojo").unmarshal().jacksonXml(TestPojo.class).to("mock:reversePojo");
            }
        };
    }

}
